#!/usr/bin/env bash

ENVFIILE=/etc/prometheus/node_exporter/portage_exporter.env
[[ -f "$ENVFIILE" ]] && source "$ENVFIILE"

REPO_BASE=${REPO_BASE:-/home/backup/borg}
TEXTFILE_COLLECTOR_DIR=${TEXTFILE_COLLECTOR_DIR:-/var/lib/node_exporter/}

PROM_FILE=$TEXTFILE_COLLECTOR_DIR/portage.prom
TMP_FILE=$PROM_FILE.$$
function dumpInfo () {
  local root="$1"
  if [[ "$root" == "/" ]] ; then
    local mychroot=()
  else
    local mychroot=( chroot "$root" )
  fi
  portage_timestamp="/usr/portage/metadata/timestamp"
  age_seconds="$(( $(date +%s) - $("${mychroot[@]}" date +%s -r "$portage_timestamp") ))"
  update_count="$("${mychroot[@]}" eix -u -c | wc -l)"
  selected_update_count="$("${mychroot[@]}" eix -u -c --selected | wc -l)"
  glsa_count="$("${mychroot[@]}" glsa-check -t all 2> /dev/null | wc -l )"
  echo portage_age_seconds\{host=\""$HOSTNAME"\", root=\""$root"\"\} "$age_seconds"
  echo portage_package_update_count\{host=\""$HOSTNAME"\", root=\""$root"\"\} "$update_count"
  echo portage_selected_package_update_count\{host=\""$HOSTNAME"\", root=\""$root"\"\} "$selected_update_count"
  echo portage_glsa_count\{host=\""$HOSTNAME"\", root=\""$root"\"\} "$glsa_count"
}

HOSTNAME=${HOSTNAME:-$(hostname)}

(
  echo "# TYPE portage_age_seconds gauge"
  echo "# TYPE update_count gauge"
  echo "# TYPE selected_update_count gauge"
  echo "# TYPE glsa_count gauge"

  dumpInfo "/"
) > "$TMP_FILE"

for root in "${CHROOTS[@]}"; do
  dumpInfo "$root"
done >> "$TMP_FILE"

mv "$TMP_FILE" "$PROM_FILE"
